Learn R Programming

hydReng (version 1.0.0)

scour_groyne: Scour depth formed by a groyne

Description

Calculate scour depth formed by a groyne

Usage

scour_groyne(v,Fr,B,h,J,L,d16,dm,d84,Ks,delta,Kb=NULL,l=NULL, fs=0,
method="Froehlich",bedload=FALSE)

Value

T0

water table at maximal scour depth [m]

S

difference between bed elevation at the middle of the river and the maximal scour depth [m]

Arguments

v

flow velocity upstream the groyne [m/s]

Fr

Froude number upstream the groyne [-]

B

sole width [m]

h

flow depth upstream the groyne [m]

J

bottom slope [-]

L

length of the groyne (perpendicular to the river) [m]

d16

d16 of grain size distribution [mm]

dm

d50 of grain size distribution [mm]

d84

d84 of grain size distribution [mm]

Ks

shape value according to "Froehlich". values between 0.55 and 1 are recomended.[-]

delta

horizontal angle of the groyne in respect to the river [°]

Kb

shape value according to "Hoffmanns" [-]

l

length of the groyne (parallel to the river)[m]

fs

safety factor [-]

method

method to calculate scour depth. valid values are "Froehlich"

bedload

Consider bedload transportation if bedload =TRUE

References

Bezzola (2012). Vorlesungsmanuskript Flussbau. ETH Zürich.

Examples

Run this code
## calculate scour depth accordint to Froehlich without bedload

v <- 2.7
Fr <- 0.52
h <- 3.31
J <- 0.0022
L <- 5
d16 <- 50
dm <- 80
d84 <- 200
Ks <- 0.82
delta <- 60

scour_groyne(
  v = v, Fr = Fr, h = h, J = J, L = L,
  d16 = d16, dm = dm, d84 = d84,
  Ks = Ks, delta = delta
)

## calculate scour depth accordint to Froehlich with bedload

v <- 2.7
Fr <- 0.52
h <- 3.31
J <- 0.0022
L <- 5
Ks <- 0.82
delta <- 60

scour_groyne(
  v = v, Fr = Fr, h = h, J = J, L = L,
  d16 = d16, dm = dm, d84 = d84,
  Ks = Ks, delta = delta, bedload = TRUE
)

Run the code above in your browser using DataLab