## calculate scour depth accordint to Eggenberger returing all results
scour_horz(Q = 4, B = 1, h = 5, h_u = 1.76, d90 = 150, a = 1, mu = 0.6)
## calculate scour depth accordint to Eggenberger with given W value
scour_horz(Q = 4, B = 1, h = 5, h_u = 1.76, d90 = 150, W = 15.4)
## calculate scour depth accordint to Shalash with l0=5
scour_horz(
Q = 4, B = 1, h = 5, h_u = 1.76, d90 = 150,
method = "Shalash", l0 = 5, a = 1
)
Run the code above in your browser using DataLab